@@ -14,9 +14,7 @@ class ImagesPanel(Widget):
         images = get_images()
 
         image_table = Table(
-            box=box.SIMPLE_HEAVY,
-            show_header=True,
-            header_style="bold bright_blue"
+            box=box.SIMPLE_HEAVY, show_header=True, header_style="bold bright_blue"
         )
 
         for header in self._HEADERS:
@@ -27,8 +25,8 @@ class ImagesPanel(Widget):
                 image.name,
                 image.tag,
                 image.image_id,
-                image.created,
-                str(image.size_bytes),
+                str(image.created),
+                "{:.2f} MB".format(float(image.size_bytes) / 1000000),
             )
 
         yield Static(Panel(image_table, title="Images"))
